@@ -17,12 +17,25 @@
 """Contains common constants for PyPI release scripts."""
 __author__ = 'api.msaniscalchi@gmail.com (Mark Saniscalchi)'
 
+import warnings
 from adspygoogle.common import GenerateLibSig
-from adspygoogle.adwords.AdWordsClient import AdWordsClient
-from adspygoogle.dfa.DfaClient import DfaClient
-from adspygoogle.dfp.DfpClient import DfpClient
 
-LIB_PYPI_VERSION = '1.1.1'
+try:
+  from adspygoogle.adwords.AdWordsClient import AdWordsClient
+except ImportError, e:
+  warnings.warn('Can\'t import AdWordsClient: %s' % e)
+
+try:
+  from adspygoogle.dfa.DfaClient import DfaClient
+except ImportError, e:
+  warnings.warn('Can\'t import DfaClient: %s' % e)
+
+try:
+  from adspygoogle.dfp.DfpClient import DfpClient
+except ImportError, e:
+  warnings.warn('Can\'t import DfpClient: %s' % e)
+
+LIB_PYPI_VERSION = '1.1.2'
 LIB_PYPI_NAME = 'Google Ads Python Client Library'
 LIB_PYPI_SHORT_NAME = 'adspygoogle'
 LIB_PYPI_URL = 'http://code.google.com/p/google-api-ads-python'
